@@ -46,7 +46,8 @@ enum {
 
 static guint gconf_cell_signals[LAST_SIGNAL] = { 0 };
 
-static GtkCellRendererClass *parent_class;
+G_DEFINE_TYPE(GConfCellRenderer, gconf_cell_renderer, GTK_TYPE_CELL_RENDERER)
+
 
 static void
 gconf_cell_renderer_get_property (GObject *object, guint param_id, GValue *value, GParamSpec *pspec)
@@ -129,7 +130,7 @@ gconf_cell_renderer_finalize (GObject *object)
 	g_object_unref (renderer->text_renderer);
 	g_object_unref (renderer->toggle_renderer);
 
-	(* G_OBJECT_CLASS (parent_class)->finalize) (object);
+	(* G_OBJECT_CLASS (gconf_cell_renderer_parent_class)->finalize) (object);
 }
 
 static void
@@ -250,7 +251,7 @@ gconf_cell_renderer_check_writability (GConfCellRenderer *cell, const gchar *pat
 	return ret;
 }
 
-GtkCellEditable *
+static GtkCellEditable *
 gconf_cell_renderer_start_editing (GtkCellRenderer      *cell,
 				   GdkEvent             *event,
 				   GtkWidget            *widget,
@@ -299,13 +300,13 @@ gconf_cell_renderer_start_editing (GtkCellRenderer      *cell,
 }
 
 static gint
-gconf_cell_renderer_activate (GtkCellRenderer *cell,
-			      GdkEvent        *event,
-			      GtkWidget       *widget,
-			      const gchar     *path,
-			      GdkRectangle    *background_area,
-			      GdkRectangle    *cell_area,
-			      guint            flags)
+gconf_cell_renderer_activate (GtkCellRenderer      *cell,
+			      GdkEvent             *event,
+			      GtkWidget            *widget,
+			      const gchar          *path,
+			      GdkRectangle         *background_area,
+			      GdkRectangle         *cell_area,
+			      GtkCellRendererState  flags)
 {
 	GConfCellRenderer *cellvalue;
 	
@@ -417,8 +418,6 @@ gconf_cell_renderer_class_init (GConfCellRendererClass *klass)
 	GObjectClass *object_class = (GObjectClass *)klass;
 	GtkCellRendererClass *cell_renderer_class = (GtkCellRendererClass *)klass;
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	object_class->get_property = gconf_cell_renderer_get_property;
 	object_class->set_property = gconf_cell_renderer_set_property;
 	object_class->finalize = gconf_cell_renderer_finalize;
@@ -469,30 +468,7 @@ gconf_cell_renderer_init (GConfCellRenderer *renderer)
 	gtk_object_sink (GTK_OBJECT (renderer->toggle_renderer));
 }
 
-GType
-gconf_cell_renderer_get_type (void)
-{
-	static GType object_type = 0;
 
-	if (!object_type) {
-		static const GTypeInfo object_info = {
-			sizeof (GConfCellRendererClass),
-			NULL,		/* base_init */
-			NULL,		/* base_finalize */
-			(GClassInitFunc) gconf_cell_renderer_class_init,
-			NULL,		/* class_finalize */
-			NULL,		/* class_data */
-			sizeof (GConfCellRenderer),
-			0,              /* n_preallocs */
-			(GInstanceInitFunc) gconf_cell_renderer_init
-		};
-		
-		object_type = g_type_register_static (GTK_TYPE_CELL_RENDERER, "GConfCellRenderer", &object_info, 0);
-
-	}
-
-	return object_type;
-}
 
 GtkCellRenderer *
 gconf_cell_renderer_new (void)
