@@ -16,6 +16,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <config.h>
+
 #include "gconf-stock-icons.h"
 
 #include <gtk/gtkiconfactory.h>
@@ -24,40 +26,9 @@
 static const char *icon_theme_items[] =
 {
 	STOCK_BOOKMARK,
-	STOCK_ADD_BOOKMARK,
-	STOCK_EDIT_BOOKMARK
+        STOCK_EDIT_BOOKMARK
 };
 
-
-static GtkIconSet *
-create_icon_set_from_filename (const gchar *filename)
-{
-	GtkIconSet *set;
-	GtkIconSource *source;
-	GdkPixbuf *pixbuf;
-	gchar *path;
-	
-	path = g_strdup_printf (GCONF_EDITOR_IMAGEDIR"/%s", filename);
-
-	pixbuf = gdk_pixbuf_new_from_file (path, NULL);
-	g_free (path);
-	
-	if (pixbuf == NULL) {
-		return NULL;
-	}
-	
-	set = gtk_icon_set_new ();
-	source = gtk_icon_source_new ();
-	gtk_icon_source_set_pixbuf (source, pixbuf);
-	g_object_unref (pixbuf);
-	gtk_icon_source_set_size (source, GTK_ICON_SIZE_MENU);
-	gtk_icon_source_set_size_wildcarded (source, TRUE);
-	gtk_icon_set_add_source (set, source);
-	gtk_icon_source_free (source);
-	
-	return set;
-}
-
 void
 gconf_stock_icons_register (void)
 {
@@ -74,13 +45,6 @@ gconf_stock_icons_register (void)
 	icon_factory = gtk_icon_factory_new ();
 	gtk_icon_factory_add_default (icon_factory);
 
-	set = create_icon_set_from_filename ("stock-about-16.png");
-
-	if (set != NULL) {
-		gtk_icon_factory_add (icon_factory, GCONF_STOCK_ABOUT, set);
-		gtk_icon_set_unref (set);
-	}
-
 	for (i = 0; i < (int) G_N_ELEMENTS (icon_theme_items); i++)
 	{
 		set = gtk_icon_set_new ();
