@@ -24,19 +24,17 @@
 #include <gconf/gconf-client.h>
 
 #define GCONF_TYPE_TREE_MODEL		  (gconf_tree_model_get_type ())
-#define GCONF_TREE_MODEL(obj)		  (GTK_CHECK_CAST ((obj), GCONF_TYPE_TREE_MODEL, GConfTreeModel))
-#define GCONF_TREE_MODEL_CLASS(klass)	  (GTK_CHECK_CLASS_CAST ((klass), GCONF_TYPE_TREE_MODEL, GConfTreeModelClass))
-#define GCONF_IS_TREE_MODEL(obj)	  (GTK_CHECK_TYPE ((obj), GCONF_TYPE_TREE_MODEL))
-#define GCONF_IS_TREE_MODEL_CLASS(klass)  (GTK_CHECK_CLASS_TYPE ((obj), GCONF_TYPE_TREE_MODEL))
-#define GCONF_TREE_MODEL_GET_CLASS(obj)   (GTK_CHECK_GET_CLASS ((obj), GCONF_TYPE_TREE_MODEL, GConfTreeModelClass))
+#define GCONF_TREE_MODEL(obj)		  (G_TYPE_CHECK_INSTANCE_CAST ((obj), GCONF_TYPE_TREE_MODEL, GConfTreeModel))
+#define GCONF_TREE_MODEL_CLASS(klass)	  (G_TYPE_CHECK_CLASS_CAST ((klass), GCONF_TYPE_TREE_MODEL, GConfTreeModelClass))
+#define GCONF_IS_TREE_MODEL(obj)	  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GCONF_TYPE_TREE_MODEL))
+#define GCONF_IS_TREE_MODEL_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((obj), GCONF_TYPE_TREE_MODEL))
+#define GCONF_TREE_MODEL_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GCONF_TYPE_TREE_MODEL, GConfTreeModelClass))
 
 typedef struct _GConfTreeModel GConfTreeModel;
 typedef struct _GConfTreeModelClass GConfTreeModelClass;
 
 enum {
 	GCONF_TREE_MODEL_NAME_COLUMN,
-	GCONF_TREE_MODEL_CLOSED_ICON_COLUMN,
-	GCONF_TREE_MODEL_OPEN_ICON_COLUMN,
 	GCONF_TREE_MODEL_NUM_COLUMNS
 };
 
