@@ -60,8 +60,11 @@ main (gint argc, gchar **argv)
 									GNOME_PARAM_NONE);
 
 	/* Register our stock icons */
+        gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (), ICONDIR);
 	gconf_stock_icons_register ();
 
+        gtk_window_set_default_icon_name ("gconf-editor");
+
 	window = gconf_editor_application_create_editor_window (GCONF_EDITOR_WINDOW_TYPE_NORMAL);
 	gtk_widget_show_now (window);
 
